pub enum GraphDir {
Horizontal,
Vertical,
}Expand description
Direction to lay out the graph nodes.
Variants
Horizontal
The graph is laid out from left to right.
Vertical
The graph is laid out from top to bottom.