Module theme

Module theme 

Structs

ColorParams
Parameters to compute colour related CssClasses.
CssClassMerger
Common logic for merging CssClassPartials into [CssClasses].
CssClassPartials
Partial CSS class name for each theme attribute. IndexMap<ThemeAttr, String> newtype.
CssClasses
Space-separated CSS utility classes for an element. String newtype.
CssClassesAndWarnings
CssClasses for a node/edge, and warnings detected while computing the CSS utility classes.
CssClassesBuilder
Essentially a builder for CssClasses.
ElCssClasses
CSS classes for each element. IndexMap<AnyId, CssClasses> newtype.
LineParams
Parameters to compute CssClasses.
Theme
Theme to style the generated diagram.
ThemeStyles
CSS utility class partials for each element. IndexMap<AnyIdOrDefaults, CssClassPartials> newtype.
ThemeWarnings
Warnings detected while computing CSS utility classes. IndexSet<String> newtype.

Enums

AnyIdOrDefaults
Key for users to specify tailwind styles against individual nodes, edges, or tags.
HighlightState
Whether an element is focused, hovered, or active.
StyleFor
The purpose of CSS classes’ styles – element regular styles, or when a tag is interacted with.
ThemeAttr
Themeable attributes of nodes and edges.

Traits

Themeable
Types that can be rendered into a CSS compatible format, e.g. SVG or HTML elements.