pub enum HighlightState {
Normal,
Focus,
FocusHover,
Hover,
Active,
}Expand description
Whether an element is focused, hovered, or active.
Variants
Normal
The element is not focused, and the cursor is not positioned over it.
Focus
The element is focused, and the cursor is not positioned over it.
FocusHover
The element is focused, and the cursor is positioned over it.
Hover
The element is not focused, and the cursor is positioned over it.
Active
The element is clicked / pressed.